@@ -1,3 +1,5 @@
+from swiftclient.exceptions import ClientException
+
 from wal_e import retries
 from wal_e.worker.base import _Deleter
 
@@ -14,4 +16,10 @@ class Deleter(_Deleter):
         # when a particular middleware is installed), so we delete one at a
         # time.
         for blob in page:
-            self.swift_conn.delete_object(self.container, blob.name)
+            try:
+                self.swift_conn.delete_object(self.container, blob.name)
+            except ClientException as e:
+                # Swallow HTTP 404's they indicate the file doesn't exist, and
+                # that's fine, we were just going to delete it anyways
+                if e.http_status != 404:
+                    raise
